@@ -1,10 +1,12 @@
-from typing import Any, Union
+from typing import TYPE_CHECKING, Any, Union
 
 import dask.dataframe as dd
 
 import dask_sql
 from dask_sql.datacontainer import DataContainer
-from dask_sql.java import org
+
+if TYPE_CHECKING:
+    from dask_sql.java import org
 
 
 class BaseRexPlugin:
@@ -20,7 +22,7 @@ class BaseRexPlugin:
 
     def convert(
         self,
-        rex: org.apache.calcite.rex.RexNode,
+        rex: "org.apache.calcite.rex.RexNode",
         dc: DataContainer,
         context: "dask_sql.Context",
     ) -> Union[dd.Series, Any]:
